# About

ccbrowse is an open source web application for browsing data from the CloudSat and CALIPSO satellites.

## How to use

For navigation, press and drag the image. Zoom by scrolling. Read off values by double-clicking. Select UTC time with the blue progress bar above.

## Data Quality

Be aware that this is a beta version. As such, data quality is not guaranteed. Especially,

- The quality of interpolation is limited.
- Quality Control (QC) information is not shown.

## Interpolation

Data is interpolated by averaging all data points overlying a given pixel of the resulting image. When the scale of the image is greater than that of the data, ordinary nearest-neighbor interpolation is performed.

## More Information

For more information, please visit ccbrowse on github.

## License

ccbrowse is distributed under terms of the MIT license.

Copyright © 2012–2022 Peter Kuma

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the " Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.